@@ -17,19 +17,25 @@ Sub-packages
 
 ::
 
- chemistry           --- abstract data structure for chemistry
- nanosci             --- nano-science tools
- physics             --- physics tools
- scripts             --- scripts
- tools               --- tools
+ chemistry           --- chemistry package
+ electronics         --- electronics package
+ nanosci             --- nano-science package
+ physics             --- physics package
+ scripts             --- scripts for running command-line tools
+ tools               --- misc tools
 
 ::
 
  __version__   --- pykit-sci version string
 
 """
-from __future__ import print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
-__all__ = ['chemistry', 'nanosci', 'physics', 'scripts', 'tools']
+__all__ = ['chemistry',
+           'electronics',
+           'nanosci',
+           'physics',
+           'scripts',
+           'tools']
 
 from pksci.version import version as __version__
