@@ -7,9 +7,11 @@ Functions for string manipulation (:mod:`pksci.tools._strfuncs`)
 .. currentmodule:: pksci.tools._strfuncs
 
 """
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
 
-__all__ = ['concat_units', 'plural_word_check']
+import re
+
+__all__ = ['concat_units', 'plural_word_check', 'split_replace']
 
 
 def concat_units(var, units, rawstr=False, ucstr=False):
@@ -49,3 +51,25 @@ def plural_word_check(word, count):
 
     """
     return word if count == 1 else word + 's'
+
+
+def split_replace(s, re_char='\W', replace=' ', replace_with='_'):
+    """Split a string with regex and replace characters.
+
+    Parameters
+    ----------
+    s : str
+        the input string
+    re_char : str
+        regex character to split string with
+    replace : str
+        string to replace
+    replace_with : str
+        replacement string
+
+    Returns
+    -------
+    str
+
+    """
+    return ''.join(re.split(re_char, s.replace(replace, replace_with)))
