@@ -14,7 +14,7 @@ __docformat__ = 'restructuredtext'
 import argparse
 import os
 import sys
-from collections import OrderedDict
+from collections import deque, OrderedDict
 from pkg_resources import resource_filename
 
 from configobj import ConfigObj
@@ -42,7 +42,7 @@ class PlotConfig(object):
 
 
 class PlotConfigParserError(Exception):
-    """Base class for any :py:class:`PlotConfigParser` errors."""
+    """Base class for any :class:`PlotConfigParser` errors."""
     pass
 
 
@@ -51,7 +51,7 @@ class PlotConfigParser(object):
 
     Parameters
     ----------
-    argparser : :py:class:`~python:argparse.ArgumentParser`, optional
+    argparser : :class:`~python:argparse.ArgumentParser`, optional
     plotcfgfile : str
     insetcfgfile : str
     overlaycfgfile : str
@@ -70,6 +70,10 @@ class PlotConfigParser(object):
             self._args = argparser.parse_args()
             self._argdict = vars(self._args)
 
+        self._dirs = None
+        if self._args.walk_dirs is not None:
+            self._dirs = deque(self._args.walk_dirs)
+
         self._plotcfgfile = plotcfgfile
         if (plotcfgfile is None and self._args is not None and
                 self._args.plotcfgfile is None and
@@ -126,7 +130,7 @@ class PlotConfigParser(object):
         if self._args.fname_prefix is not None:
             self._plotconfig.output.fname_prefix = self._args.fname_prefix
         if self._args.frame_legend:
-            self._plotconfig.frame_legend = True
+            self._plotconfig.legend_frameon = True
         if self._args.overwrite:
             self._plotconfig.output.overwrite = True
 
@@ -173,7 +177,9 @@ class PlotConfigParser(object):
     def _parse_data(self, dataset=None):
         if dataset is not None:
             fpath = None
-            if dataset.fname is not None and os.path.isfile(dataset.fname):
+            if dataset.fname is not None and self._dirs is not None:
+                fpath = os.path.join(self._dirs.popleft(), dataset.fname)
+            elif dataset.fname is not None and os.path.isfile(dataset.fname):
                 fpath = dataset.fname
             elif dataset.path is not None and os.path.isfile(dataset.path):
                 fpath = dataset.path
@@ -392,7 +398,7 @@ class XYPlotConfigParser(PlotConfigParser):
 
     Parameters
     ----------
-    argparser : :py:class:`~python:argparse.ArgumentParser`, optional
+    argparser : :class:`~python:argparse.ArgumentParser`, optional
     plotcfgfile : {None, str}, optional
     insetcfgfile : {None, str}, optional
     overlaycfgfile : {None, str}, optional
