@@ -268,11 +268,9 @@ class XYPlot(MPLPlot):
                                overlay_config=self._plotconfig.overlay_config)
 
         if self._plotconfig.xaxis.log_scale:
-            #plt.xscale('log')
-            self._axes.xscale('log')
+            self._axes.set_xscale('log')
         if self._plotconfig.yaxis.log_scale:
-            #plt.yscale('log')
-            self._axes.yscale('log')
+            self._axes.set_yscale('log')
 
         datalimits = {'xaxis': {'left': xmin, 'right': xmax},
                       'yaxis': {'bottom': ymin, 'top': ymax}}
